Skip to contents

A small example dataset containing signal values for a genomic region. This dataset is in a format similar to what would be extracted from a bigWig file.

Usage

example_signal

Format

A data frame with 1000 rows and 3 variables:

seqnames

Chromosome name

start

Start position

end

End position

score

Signal value

Simulated data