Skip to contents

This function creates a theme specifically for gene tracks. It removes the y-axis text and title, and makes the plot more compact.

Usage

ez_gene_theme(...)

Arguments

...

Additional arguments passed to ez_theme

Value

A ggplot2 theme object

Examples

if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(data, aes(x = start, y = gene_name)) +
  geom_gene() +
  ez_gene_theme()
} # }