Skip to contents

This function creates a theme specifically for regional Manhattan plots. It provides consistent styling with other track types for use with vstack_plot().

Usage

ez_manhattan_theme(y_axis_style = c("none", "simple", "full"), ...)

Arguments

y_axis_style

Style of the y-axis. Options are "none", "simple", and "full".

  • "none": Removes all y-axis elements

  • "simple": Shows y-axis text only (no title, ticks, or line)

  • "full": Shows y-axis text and ticks Default: "none"

...

Additional arguments passed to ez_theme

Value

A ggplot2 theme object

Examples

if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(data, aes(x = pos, y = -log10(pvalue))) +
  geom_point() +
  ez_manhattan_theme()
} # }