Skip to contents

This function creates a theme specifically for sequence tracks produced by ez_sequence(). It removes all y-axis elements (the track is always a single row of colored tiles) and strips the panel background.

Usage

ez_sequence_theme(...)

Arguments

...

Additional arguments passed to ez_theme.

Value

A ggplot2 theme object.

Examples

if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(df, aes(x = position, label = nucleotide, fill = fill)) +
  geom_sequence() +
  ez_sequence_theme()
} # }