Skip to contents

This function creates a minimal, clean theme for genome track visualization. It removes most of the background elements and grid lines to focus on the data.

Usage

ez_theme(
  base_size = 10,
  base_family = "",
  base_line_size = 0.2,
  base_rect_size = 0.2,
  show_grid = FALSE,
  show_ticks = TRUE,
  show_x_axis = TRUE,
  show_y_axis = TRUE
)

Arguments

base_size

Base font size

base_family

Base font family

base_line_size

Base line size

base_rect_size

Base rect size

show_grid

Show grid lines (default: FALSE)

show_ticks

Show axis ticks (default: TRUE)

show_x_axis

Show x-axis line (default: TRUE)

show_y_axis

Show y-axis line (default: FALSE)

Value

A ggplot2 theme object

Examples

if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(data, aes(x = start, y = score)) +
  geom_line() +
  ez_theme()
} # }