R/data.R
example_signal.Rd
A small example dataset containing signal values for a genomic region. This dataset is in a format similar to what would be extracted from a bigWig file.
example_signal
A data frame with 1000 rows and 3 variables:
Chromosome name
Start position
End position
Signal value
Simulated data