This function creates a theme specifically for feature tracks. It removes the y-axis text and title, and makes the plot more compact.
Examples
if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(data, aes(x = start, y = 1)) +
geom_feature() +
ez_feature_theme()
} # }