This function creates a theme specifically for gene tracks. It removes the y-axis text and title, and makes the plot more compact.
This function creates a theme specifically for gene tracks. It removes the y-axis text and title, and makes the plot more compact.