This function creates a theme specifically for regional Manhattan plots.
It provides consistent styling with other track types for use with vstack_plot().
Usage
ez_manhattan_theme(y_axis_style = c("none", "simple", "full"), ...)This function creates a theme specifically for regional Manhattan plots.
It provides consistent styling with other track types for use with vstack_plot().
ez_manhattan_theme(y_axis_style = c("none", "simple", "full"), ...)