This function creates a minimal, clean theme for genome track visualization. It removes most of the background elements and grid lines to focus on the data.
Usage
ez_theme(
base_size = 10,
base_family = "",
base_line_size = 0.2,
base_rect_size = 0.2,
show_grid = FALSE,
show_ticks = TRUE,
show_x_axis = TRUE,
show_y_axis = TRUE
)