This function creates a continuous scale for genomic coordinates on the x-axis. It formats the axis labels in a genomic coordinate style (e.g., 1Mb, 500kb).
Examples
if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(data, aes(x = start)) + geom_point() + scale_x_genome()
} # }