Create a genomic position scale for a specific chromosome region
Source:R/scales.R
scale_x_genome_region.RdThis function creates a continuous scale for a specific chromosome region. It sets the limits to the start and end positions of the region and formats the axis labels in a genomic coordinate style.
Examples
if (FALSE) { # \dontrun{
library(ggplot2)
p <- ggplot(data, aes(x = start)) + geom_point() +
scale_x_genome_region("chr1:1000000-2000000")
} # }